@@ -12,14 +12,10 @@ class BaseDatafeed(abc.ABC):
     Base class for all datafeeds.
     """
 
-    def __init__(self, event_bus: messaging.EventBus):
-        """
-        Initialize the datafeed with an event bus.
-
-        Args:
-            event_bus (messaging.EventBus): Event bus to publish market data events to.
-        """
-        self.event_bus: messaging.EventBus = event_bus
+    def __init__(self, event_bus: messaging.EventBus | None = None):
+        self.event_bus: messaging.EventBus = (
+            event_bus if event_bus else messaging.system_event_bus
+        )
 
     @abc.abstractmethod
     def connect(self):
