@@ -1,8 +1,8 @@
 """
 This module provides the event messages used for decoupled communication between the
  trading infrastructure's components.
-Events are organized into namespaces (`Market`, `Request`, `Response`, and `System`)
- to provide clear semantic groupings.
+Events are organized into namespaces (`Strategy`, `Market`, `Request`, `Response`, and
+`System`) to provide clear semantic groupings.
 Base event messages used for structure inheritance are grouped under the
  `Base` namespace.
 Dataclass field validation logic is grouped under the `_Validate` namespace.
@@ -23,11 +23,13 @@ Dataclass field validation logic is grouped under the `_Validate` namespace.
     R22[events.Base.CancelRequest]
     R3[events.Base.Response]
     R4[events.Base.System]
+    R5[events.Base.Strategy]
 
     R --> R1
     R --> R2
     R --> R3
     R --> R4
+    R --> R5
 
     R2 --> R21
     R2 --> R22
@@ -83,6 +85,17 @@ Dataclass field validation logic is grouped under the `_Validate` namespace.
 
     style D1 fill:#6F42C1,fill-opacity:0.3
 
+    E1[events.Strategy.SymbolRelease]
+    E2[events.Strategy.SymbolAssignment]
+    E3[events.Strategy.StopTrading]
+
+    R5 --> E1
+    R5 --> E2
+    R5 --> E3
+
+    style E1 fill:#6F42C1,fill-opacity:0.3
+    style E2 fill:#6F42C1,fill-opacity:0.3
+    style E3 fill:#6F42C1,fill-opacity:0.3
 
     subgraph Market ["Market Update Event Messages"]
         R1
@@ -143,6 +156,20 @@ Dataclass field validation logic is grouped under the `_Validate` namespace.
             D1
         end
 
+    end
+
+    subgraph Strategy ["Strategy Coord. Event Messages"]
+        R5
+        E1
+        E2
+        E3
+
+        subgraph StrategyNamespace ["events.Strategy Namespace"]
+            E1
+            E2
+            E3
+        end
+
     end
     ```
 """
@@ -153,6 +180,7 @@ import re
 import uuid
 from onesecondtrader.core import models
 from onesecondtrader.monitoring import console
+from onesecondtrader.strategies import base_strategy
 
 
 class Base:
@@ -280,7 +308,7 @@ class Base:
             )
             _Validate.quantity(self.quantity, f"Order {self.order_id}")
 
-            if self.time_in_force.value == 4:
+            if self.time_in_force is models.TimeInForce.GTD:
                 if self.order_expiration is None:
                     console.logger.error(
                         f"Order {self.order_id}: GTD order missing expiration "
@@ -345,6 +373,36 @@ class Base:
                 )
             return super().__new__(cls)
 
+    @dataclasses.dataclass(kw_only=True, frozen=True)
+    class Strategy(Event):
+        """
+        Base event message dataclass for strategy coordination messages.
+        This dataclass cannot be instantiated directly.
+
+        Attributes:
+            ts_event: Timestamp of the event. (defaults to current UTC time;
+                auto-generated)
+        """
+
+        ts_event: pd.Timestamp = dataclasses.field(
+            default_factory=lambda: pd.Timestamp.now(tz="UTC")
+        )
+        strategy: base_strategy.Strategy
+
+        def __new__(cls, *args, **kwargs):
+            if cls is Base.Strategy:
+                console.logger.error(
+                    f"Cannot instantiate abstract class '{cls.__name__}' directly"
+                )
+            return super().__new__(cls)
+
+        def __post_init__(self) -> None:
+            super().__post_init__()
+            if not isinstance(self.strategy, base_strategy.Strategy):
+                console.logger.error(
+                    f"{type(self).__name__}: strategy must inherit from Strategy"
+                )
+
 
 class Market:
     """
@@ -374,7 +432,7 @@ class Market:
             ...         volume=10000,
             ...     ),
             ... )
-            ```
+
         """
 
         bar: models.Bar
@@ -621,7 +679,7 @@ class Response:
 
             gross_value = self.filled_at_price * self.quantity_filled
 
-            if self.side.value == 1:
+            if self.side is models.Side.BUY:
                 net_value = gross_value + self.commission_and_fees
             else:
                 net_value = gross_value - self.commission_and_fees
@@ -699,6 +757,74 @@ class System:
         pass
 
 
+class Strategy:
+    """
+    Namespace for strategy coordination event messages.
+    """
+
+    @dataclasses.dataclass(kw_only=True, frozen=True)
+    class SymbolRelease(Base.Strategy):
+        """
+        Event to indicate a strategy releases ownership of a symbol.
+
+        Attributes:
+            symbol (str): Symbol released.
+
+        Examples:
+            >>> from onesecondtrader.messaging import events
+            >>> event = events.Strategy.SymbolRelease(
+            ...     symbol="AAPL",
+            ... )
+        """
+
+        symbol: str
+
+        def __post_init__(self) -> None:
+            super().__post_init__()
+            _Validate.symbol(self.symbol, "Strategy.SymbolRelease")
+
+    @dataclasses.dataclass(kw_only=True, frozen=True)
+    class SymbolAssignment(Base.Strategy):
+        """
+        Event message to indicate that a symbol should be assigned to a strategy.
+
+        Attributes:
+            symbol_list (list[str]): List of symbols to be assigned.
+
+        Examples:
+            >>> from onesecondtrader.messaging import events
+            >>> event = events.Strategy.SymbolAssignment(
+            ...     strategy=my_strategy,
+            ...     symbol=["AAPL"],
+            ... )
+        """
+
+        symbol_list: list[str]
+
+        def __post_init__(self) -> None:
+            super().__post_init__()
+            for symbol in self.symbol_list:
+                _Validate.symbol(symbol, "Strategy.SymbolAssignment")
+
+    @dataclasses.dataclass(kw_only=True, frozen=True)
+    class StopTrading(Base.Strategy):
+        """
+        Event to indicate a strategy should stop trading.
+
+        Attributes:
+            shutdown_mode (models.StrategyShutdownMode): Shutdown mode to use.
+
+        Examples:
+            >>> from onesecondtrader.messaging import events
+            >>> event = events.Strategy.StopTrading(
+            ...     strategy=my_strategy,
+            ...     shutdown_mode=models.StrategyShutdownMode.SOFT,
+            ... )
+        """
+
+        shutdown_mode: models.StrategyShutdownMode
+
+
 class _Validate:
     """Internal validation utilities for events."""
 
